==========================
ok-esputnik |PyPI version|
==========================

|Build Status| |Code Health| |Python Versions| |Requirements Status| |license| |PyPI downloads|

Simple E-Sputnik REST client library for Python.

Installation
------------

Install with pip:

.. code:: shell

    $ pip install ok-esputnik


Usage
-----

See a list of examples `here`_.


.. _here: https://github.com/LowerDeez/ok-esputnik/blob/master/esputnik/examples/cases.py

.. |PyPI version| image:: https://badge.fury.io/py/ok-esputnik.svg
   :target: https://badge.fury.io/py/ok-esputnik
.. |Build Status| image:: https://travis-ci.org/LowerDeez/ok-esputnik.svg?branch=master
   :target: https://travis-ci.org/LowerDeez/ok-esputnik
   :alt: Build status
.. |Code Health| image:: https://api.codacy.com/project/badge/Grade/147156648567470b9c948d2ef0ecf76f    
   :target: https://www.codacy.com/app/LowerDeez/ok-esputnik
   :alt: Code health
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/ok-esputnik.svg
   :target: https://pypi.org/project/django-ok-esputnik/
   :alt: Python versions
.. |license| image:: https://img.shields.io/pypi/l/ok-esputnik.svg
   :alt: Software license
   :target: https://github.com/LowerDeez/ok-esputnik/blob/master/LICENSE
.. |PyPI downloads| image:: https://img.shields.io/pypi/dm/ok-esputnik.svg
   :alt: PyPI downloads
.. |Requirements Status| image:: https://requires.io/github/LowerDeez/ok-esputnik/requirements.svg?branch=master
